@@ -10,9 +10,11 @@
 #include <afs/param.h>
 #include <afs/stds.h>
 
+#ifndef DJGPP
 #include <windows.h>
-#include <stddef.h>
 #include <winsock2.h>
+#endif /* !DJGPP */
+#include <stddef.h>
 #include <malloc.h>
 #include <string.h>
 #include <stdlib.h>
@@ -26,6 +28,10 @@
 #define ROVOL	1
 #define BACKVOL	2
 
+#ifdef DEBUG
+extern void afsi_log(char *pattern, ...);
+#endif
+
 unsigned int cm_mountRootGen = 0;
 
 char cm_sysName[100];
@@ -957,6 +963,7 @@ long cm_Lookup(cm_scache_t *dscp, char *namep, long flags, cm_user_t *userp,
         cm_scache_t *mountedScp;
         cm_lookupSearch_t rock;
         char tname[256];
+	int getroot;
 
 	if (dscp->fid.vnode == 1 && dscp->fid.unique == 1
 	    && strcmp(namep, "..") == 0) {
@@ -986,12 +993,27 @@ long cm_Lookup(cm_scache_t *dscp, char *namep, long flags, cm_user_t *userp,
 	 * looking for.  Any other non-zero code is an error.
          */
         if (code && code != CM_ERROR_STOPNOW) return code;
-        
-        if (!rock.found)
+
+	getroot = (dscp==cm_rootSCachep) ;
+        if (!rock.found) {
+	  if (!cm_freelanceEnabled || !getroot) {
 		if (flags & CM_FLAG_CHECKPATH)
 			return CM_ERROR_NOSUCHPATH;
 		else
 			return CM_ERROR_NOSUCHFILE;
+	  }
+	  else {  /* nonexistent dir on freelance root, so add it */
+	    code = cm_FreelanceAddMount(namep, namep, "root.cell.",
+					&rock.fid);
+	    if (code < 0) {   /* add mount point failed, so give up */
+	      if (flags & CM_FLAG_CHECKPATH)
+		return CM_ERROR_NOSUCHPATH;
+	      else
+		return CM_ERROR_NOSUCHFILE;
+	    }
+	    tscp = NULL;   /* to force call of cm_GetSCache */
+	  }
+	}
         
 haveFid:       
 	if ( !tscp )    /* we did not find it in the dnlc */
@@ -1057,6 +1079,14 @@ long cm_Unlink(cm_scache_t *dscp, char *namep, cm_user_t *userp, cm_req_t *reqp)
         AFSFetchStatus newDirStatus;
         AFSVolSync volSync;
 
+#ifdef AFS_FREELANCE_CLIENT
+	if (cm_freelanceEnabled && dscp == cm_rootSCachep) {
+	  /* deleting a mount point from the root dir. */
+	  code = cm_FreelanceRemoveMount(namep);
+	  return code;
+	}
+#endif
+
 	/* make sure we don't screw up the dir status during the merge */
         lock_ObtainMutex(&dscp->mx);
 	sflags = CM_SCACHESYNC_STOREDATA;
@@ -1180,9 +1210,17 @@ long cm_AssembleLink(cm_scache_t *linkScp, char *pathSuffixp,
                 *newRootScpp = cm_rootSCachep;
                 cm_HoldSCache(cm_rootSCachep);
         } else if (*linkp == '\\' || *linkp == '/') {
+	  /* formerly, this was considered to be from the AFS root,
+	     but this seems to create problems.  instead, we will just
+	     reject the link */
+#if 0
 		strcpy(tsp->data, linkp+1);
                 *newRootScpp = cm_rootSCachep;
                 cm_HoldSCache(cm_rootSCachep);
+#else
+		code = CM_ERROR_NOSUCHPATH;
+		goto done;
+#endif
         }
         else {
 		/* a relative link */
@@ -1497,6 +1535,21 @@ long cm_TryBulkProc(cm_scache_t *scp, cm_dirEntry_t *dep, void *rockp,
                 cm_ReleaseSCache(tscp);
         }	/* found entry */
 
+#ifdef AFS_FREELANCE_CLIENT
+	// yj: if this is a mountpoint under root.afs then we don't want it
+	// to be bulkstat-ed, instead, we call getSCache directly and under
+	// getSCache, it is handled specially.
+	if 	(cm_freelanceEnabled &&
+           tfid.cell==0x1 && tfid.volume==0x20000001 &&
+			   !(tfid.vnode==0x1 && tfid.unique==0x1) )
+	{
+#ifdef DEBUG
+	        afsi_log("   cm_trybulkproc going to call getscache");
+#endif
+		return cm_GetSCache(&tfid, &tscp, NULL, NULL);
+	}
+#endif /* AFS_FREELANCE_CLIENT */
+
 	i = bsp->counter++;
         bsp->fids[i].Volume = scp->fid.volume;
         bsp->fids[i].Vnode = tfid.vnode;
@@ -2178,6 +2231,10 @@ long cm_Rename(cm_scache_t *oldDscp, char *oldNamep, cm_scache_t *newDscp,
 	 * which makes the code a little verbose.
          */
 	if (oldDscp == newDscp) {
+                /* check for identical names */
+                if (strcmp(oldNamep, newNamep) == 0)
+                        return CM_ERROR_RENAME_IDENTICAL;
+
 		oneDir = 1;
 		lock_ObtainMutex(&oldDscp->mx);
 		cm_dnlcRemove(oldDscp, oldNamep);
