@@ -10,33 +10,40 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/rx/rx_multi.c,v 1.4 2001/07/12 19:58:56 shadow Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/rx/rx_multi.c,v 1.8 2003/11/11 19:03:09 rees Exp $");
 
 #ifdef	KERNEL
-#include "../rx/rx_kernel.h"
-#include "../rx/rx_multi.h"
+#include "afs/sysincludes.h"
+#include "rx/rx.h"
 #else /* KERNEL */
-# include "rx_user.h"
-# include "rx_multi.h"
-# include "rx_internal.h"
+# include "rx.h"
 #endif /* KERNEL */
 
-/* multi.c and multi.h, together with some rxgen hooks, provide a way of making multiple, but similar, rx calls to multiple hosts simultaneously */
+/*
+ * multi.c and multi.h, together with some rxgen hooks, provide a way of
+ * making multiple, but similar, rx calls to multiple hosts simultaneously
+ */
 
-struct multi_handle *multi_Init(conns, nConns)
-    struct rx_connection **conns;
-    register int nConns;
+struct multi_handle *
+multi_Init(struct rx_connection **conns, register int nConns)
 {
-    void multi_Ready();
     register struct rx_call **calls;
     register short *ready;
     register struct multi_handle *mh;
     register int i;
-    /* Note:  all structures that are possibly referenced by other processes must be allocated.  In some kernels variables allocated on a process stack will not be accessible to other processes */
-    calls = (struct rx_call **)osi_Alloc(sizeof (struct rx_call *) * nConns);
-    ready = (short *) osi_Alloc(sizeof(short *) * nConns);
-    mh = (struct multi_handle *) osi_Alloc(sizeof (struct multi_handle));
-    if (!calls || !ready || !mh) osi_Panic("multi_Rx: no mem\n");
+
+    /*
+     * Note: all structures that are possibly referenced by other
+     * processes must be allocated.  In some kernels variables allocated on
+     * a process stack will not be accessible to other processes
+     */
+
+    calls = (struct rx_call **)osi_Alloc(sizeof(struct rx_call *) * nConns);
+    ready = (short *)osi_Alloc(sizeof(short *) * nConns);
+    mh = (struct multi_handle *)osi_Alloc(sizeof(struct multi_handle));
+    if (!calls || !ready || !mh)
+	osi_Panic("multi_Rx: no mem\n");
     mh->calls = calls;
     mh->nextReady = mh->firstNotReady = mh->ready = ready;
     mh->nReady = 0;
@@ -45,17 +52,17 @@ struct multi_handle *multi_Init(conns, nConns)
     MUTEX_INIT(&mh->lock, "rx_multi_lock", MUTEX_DEFAULT, 0);
     CV_INIT(&mh->cv, "rx_multi_cv", CV_DEFAULT, 0);
 #endif /* RX_ENABLE_LOCKS */
-    for (i=0; i<nConns; i++) {
+    for (i = 0; i < nConns; i++) {
 	register struct rx_call *call;
 	call = mh->calls[i] = rx_NewCall(conns[i]);
-	rx_SetArrivalProc(call, multi_Ready, (VOID *)mh, (VOID *)i);
+	rx_SetArrivalProc(call, multi_Ready, (VOID *) mh, (VOID *) i);
     }
     return mh;
 }
 
 /* Return the user's connection index of the most recently ready call; that is, a call that has received at least one reply packet */
-int multi_Select(mh)
-    register struct multi_handle *mh;
+int
+multi_Select(register struct multi_handle *mh)
 {
     int index;
     SPLVAR;
@@ -87,10 +94,9 @@ int multi_Select(mh)
 }
 
 /* Called by Rx when the first reply packet of a call is received, or the call is aborted. */
-void multi_Ready(call, mh, index)
-    register struct rx_call *call;
-    register struct multi_handle *mh;
-    register int index;
+void
+multi_Ready(register struct rx_call *call, register struct multi_handle *mh,
+	    register int index)
 {
 #ifdef RX_ENABLE_LOCKS
     MUTEX_ENTER(&mh->lock);
@@ -106,39 +112,41 @@ void multi_Ready(call, mh, index)
 }
 
 /* Called when the multi rx call is over, or when the user aborts it (by using the macro multi_Abort) */
-void multi_Finalize(mh)
-register struct multi_handle *mh;
+void
+multi_Finalize(register struct multi_handle *mh)
 {
     register int i;
     register int nCalls = mh->nConns;
-    for (i=0; i<nCalls; i++) {
+    for (i = 0; i < nCalls; i++) {
 	register struct rx_call *call = mh->calls[i];
-	if (call) rx_EndCall(call, RX_USER_ABORT);
+	if (call)
+	    rx_EndCall(call, RX_USER_ABORT);
     }
 #ifdef RX_ENABLE_LOCKS
     MUTEX_DESTROY(&mh->lock);
     CV_DESTROY(&mh->cv);
 #endif /* RX_ENABLE_LOCKS */
-    osi_Free(mh->calls, sizeof (struct rx_call *) * nCalls);
+    osi_Free(mh->calls, sizeof(struct rx_call *) * nCalls);
     osi_Free(mh->ready, sizeof(short *) * nCalls);
     osi_Free(mh, sizeof(struct multi_handle));
 }
 
 /* ignores all remaining multiRx calls */
-void multi_Finalize_Ignore(mh)
-register struct multi_handle *mh;
+void
+multi_Finalize_Ignore(register struct multi_handle *mh)
 {
     register int i;
     register int nCalls = mh->nConns;
-    for (i=0; i<nCalls; i++) {
+    for (i = 0; i < nCalls; i++) {
 	register struct rx_call *call = mh->calls[i];
-	if (call) rx_EndCall(call, 0);
+	if (call)
+	    rx_EndCall(call, 0);
     }
 #ifdef RX_ENABLE_LOCKS
     MUTEX_DESTROY(&mh->lock);
     CV_DESTROY(&mh->cv);
 #endif /* RX_ENABLE_LOCKS */
-    osi_Free(mh->calls, sizeof (struct rx_call *) * nCalls);
+    osi_Free(mh->calls, sizeof(struct rx_call *) * nCalls);
     osi_Free(mh->ready, sizeof(short *) * nCalls);
     osi_Free(mh, sizeof(struct multi_handle));
 }
